summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/template.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/template.h
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/template.h')
-rw-r--r--umbrello/umbrello/template.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/template.h b/umbrello/umbrello/template.h
index 6b471207..e7558010 100644
--- a/umbrello/umbrello/template.h
+++ b/umbrello/umbrello/template.h
@@ -30,20 +30,20 @@ public:
/**
* Sets up a template.
*
* @param parent The parent of this UMLTemplate (i.e. its concept).
* @param name The name of this UMLTemplate.
* @param id The unique id given to this UMLTemplate.
* @param type The type of this UMLTemplate.
*/
- UMLTemplate(const UMLObject *parent, const TQString& name,
+ UMLTemplate(const UMLObject *tqparent, const TQString& name,
Uml::IDType id = Uml::id_None, const TQString& type = "class");
/**
* Sets up a template.
*
* @param parent The parent of this UMLTemplate (i.e. its concept).
*/
- UMLTemplate(const UMLObject *parent);
+ UMLTemplate(const UMLObject *tqparent);
/**
* Overloaded '==' operator
@@ -89,7 +89,7 @@ public:
*
* @return Success status.
*/
- bool showPropertiesDialog(TQWidget* parent);
+ bool showPropertiesDialog(TQWidget* tqparent);
/**
* Writes the <UML:TemplateParameter> XMI element.
@@ -30,20 +30,20 @@ public:
* Sets up a template.
*
- * @param parent The parent of this UMLTemplate (i.e. its concept).
+ * @param tqparent The tqparent of this UMLTemplate (i.e. its concept).
* @param name The name of this UMLTemplate.
* @param id The unique id given to this UMLTemplate.
@@ -30,20 +30,20 @@ public:
* Sets up a template.
*
- * @param parent The parent of this UMLTemplate (i.e. its concept).
+ * @param tqparent The tqparent of this UMLTemplate (i.e. its concept).
*/